# Metadata for the widget EGG. Should leave it for the (unimplemented) widget
# tracker to track it

__DISTRIBUTION__ = 'tw.uitheme'
__DESCRIPTION__ = 'theming for jquery plugins packaged as tosca widgets ressources, based on 1.8.9'
__URL__ = 'http://jqueryui.com/themeroller/'
__VERSION__ = '0.2.2'
__AUTHOR__ = 'Nicolas Laurance'
__EMAIL__ = 'nicolas[dot]laurance[at]gmail[dot]com'
__COPYRIGHT__ = "Copyright 2010 Nicolas Laurance"
__LICENSE__ = 'GPL'
